#!/bin/sh

#   Copyright 2009 (c)
#   Zebooka (Anton Bondar) <anton@zebooka.com> http://www.zebooka.com
#   $Id: zebooka-resizer.sh 330 2009-10-08 14:43:41Z zebooka $
#
#   LICENSE
#
#   Permission is hereby granted, free of charge, to any person obtaining a 
#   copy of this software and associated documentation files (the "Software"), 
#   to deal in the Software without restriction, including without limitation 
#   the rights to use, copy, modify, merge, publish, distribute the Software, 
#   and to permit persons to whom the Software is furnished to do so, subject 
#   to the following conditions:
#   
#   The above copyright notice and this permission notice shall be included 
#   in all copies or substantial portions of the Software.
#   
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
#   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
#   THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
#   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
#   DEALINGS IN THE SOFTWARE.
#   
#   NOTE: YOU CAN NOT SELL THIS SOFTWARE. ONLY FREE DISTRIBUTION.
#
#   INSTALLATION
#
#   Just copy this script to somewhere specified in PATH variable,
#   for example '/usr/local/bin/'. And don't forget to set 'chmod a+x'
#   execution flag to it.


#   WARNING! Don't change anything below (unless you are guru).
#   =========================================================================

Error () { echo "\033[0;30;41m ERROR: \033[1;37m${1} \033[0;39;49m\n"; }
Warning () { echo "\033[0;30;43m WARNING: \033[1;30m${1} \033[0;39;49m\n"; }
Success () { echo "\033[0;30;42m SUCCESS: \033[1;32;49m ${1} \033[0;39;49m\n"; }
Notice () { echo "\033[0;30;46m NOTICE: \033[1;36;49m ${1} \033[0;39;49m\n"; }

# output usage info
Usage () {
	echo "\033[4mUSAGE\033[0m:"
	echo "   \033[1m${0}\033[0m [-h] [-r] [-q QUALITY] [-s WxH] FROM_PATH [TO_PATH]"
	echo ""
	echo "   FROM_PATH              Images from this folder are processed."
	echo "   TO_PATH                They are saved to this folder. By default"
	echo "                          script will create subfolder 'resized-YYYY-MM-DD'"
	echo ""
	echo "\033[4mPARAMETERS\033[0m:"
	echo "   -h                     This help message."
	echo "   -e                     Remove EXIF from resized image."
	echo "   -r or -R               Process directory recursively. [NOT IMPLEMENTED YET]"
	echo "   -q QUALITY             Quality of resized jpeg, from 0% to 100%. Default: 85%"
	echo "   -d WxH                 Max dimentions (width and height) to fit image. Default: 700x700"
	echo "   -s SHARP               Sharp image with unsharpen mask. Types: no, light, hard, extra."
	echo "                          Default: light. For manual sharpening define:"
	echo "                          RADIUSxSIGMA+AMOUNT+THRESHOLD (more -> man ImageMagick)."
	echo "   -p STRING              Prepend string to resized file name."
	echo "   -a STRING              Append string to resized file name (before last extension)."
	echo "   -b STRING              Append string to resized file name (before first extension)."
	echo ""
}

# process folder
ResizeFolder () {
	cd "$1"
	mkdir -vp "$2"
	OPT_RECURSIVE2=''
	if [ -z $OPT_RECURSIVE -o $OPT_RECURSIVE -eq 0 ]; then 
		OPT_RECURSIVE2='-maxdepth 1'
		echo "Searching for photos..."
	else
		echo "Searching for photos, recursively..."
	fi
	OPT_NOEXIF2=''
	if [ $OPT_NOEXIF -eq 1 ]; then
		OPT_NOEXIF2='-strip'
	fi
	P=`find $OPT_RECURSIVE2 -iname '*.jpg' -o -iname '*.jpeg'`
	PCOUNT=`echo "$P" | wc -l`
	echo "${PCOUNT} photos found."
	echo ""
	C=0
	echo "$P" | while read F; do
		C=$(($C+1))
		echo "\033[0;36mProcessing photo ${C} of ${PCOUNT} [\033[1;36m$((100 * $C / $PCOUNT))%\033[0;36m],\033[2;36m $(($PCOUNT - $C)) photo(s) left\033[2;39m"
		F2="$(dirname "$F")/${OPT_PREFIX}$(echo "$(basename "$F")" | sed "s*\.*${OPT_SUFFIX2}\.*" | sed "s*\.[^\.]\+\$*${OPT_SUFFIX}&*")"
		# $(echo "$(basename $F)" | sed 's|||')"
		F22=`dirname "${2}${F2}"`
		if [ ! -e "${F22}" ]; then
			mkdir -vp "${F22}"
		fi
		convert "$F" -verbose -unsharp $OPT_SHARP -quality $OPT_QUALITY $OPT_NOEXIF2 -resize $OPT_SIZE\> "${2}${F2}"
	done
	echo "\033[0;39;49m"
}

# print header
echo ""
echo "\033[1mZEBOOKA-RESIZER\033[0;2m, version$Rev: 330 $Hide, date$Date: 2009-10-08 21:43:41 +0700 (Чтв, 08 Окт 2009) $Hide"
echo "\033[0m(c) Copyright 2009, \033[32mZebooka (Anton Bondar)  \033[36m<anton@zebooka.com>  http://www.zebooka.com"
echo "\033[0;39;49m"

if [ ! `which convert` ]; then
	Error "ImageMagick required for this script to work. Please install it."
	exit 1
fi

# get params
OPT_SIZE="700x700"
OPT_QUALITY="85%"
OPT_NOEXIF=0
OPT_SHARP="0x3+0.7+0"
OPT_RECURSIVE=0
OPT_PREFIX=""
OPT_SUFFIX=""
OPT_SUFFIX2=""
while getopts ":rRhed:q:s:p:a:b:" Option
do
	case $Option in
		e) OPT_NOEXIF=1 ;;
		q) OPT_QUALITY=$OPTARG ;;
		d) OPT_SIZE=$OPTARG ;;
		p) OPT_PREFIX=$OPTARG ;;
		a) OPT_SUFFIX=$OPTARG ;;
		b) OPT_SUFFIX2=$OPTARG ;;
		r|R) OPT_RECURSIVE=1 ;;
		s) 
			case $OPTARG in
				no) OPT_SHARP="0" ;;
				light) ;;
				hard) OPT_SHARP="0x3+1.3+0" ;;
				extra) OPT_SHARP="0x5+1.7+0" ;;
				*) OPT_SHARP="${OPTARG}" ;;
			esac
			;;
		h)
			Usage
			exit 0
			;;
	esac
done
shift `expr $OPTIND - 1`

OPT_FROM=$1
if [ ! "$OPT_FROM" ]; then
	Error "No FROM_PATH specified."
	Usage
	exit 3
fi
OPT_FROM="`echo "$OPT_FROM" | sed 's/\/$//'`/"
echo "Processing photos from: \033[4m$OPT_FROM\033[0m"

OPT_TO=$2
if [ -z "${OPT_TO}" ]; then
	OPT_TO="`echo "${OPT_FROM}" | sed 's/\/$//'`/resized-`date +%Y%m%d-%H%M%S`/"
	Notice "TO_PATH for resized files not specified. Using default: \033[4m${OPT_TO}\033[0m"
else
	OPT_TO="`echo "${OPT_TO}" | sed 's/\/$//'`/"
	echo "Resized files will be saved to: \033[4m${OPT_TO}\033[0m"
fi

echo ""
ResizeFolder "${OPT_FROM}" "${OPT_TO}"

echo "\033[0m"
Success "Photos processed succefully in \033[4m${OPT_FROM}\033[0m"
echo "\033[0;39;49m"
#sleep 2s
exit 0

